@@ -4,25 +4,25 @@
  *
  * Copyright (C) 2009 Canonical, Ltd. (www.canonical.com)
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 3 of the GNU Lesser General Public
- * License as published by the Free Software Foundation.
- *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
  */
 
 #include <libebackend/e-data-server-module.h>
 #include <libedata-book/e-book-backend-factory.h>
+#include <dbus/dbus.h>
 #include "e-book-backend-couchdb.h"
 
 E_BOOK_BACKEND_FACTORY_SIMPLE (couchdb, CouchDB, e_book_backend_couchdb_new)
@@ -33,6 +33,9 @@ void
 eds_module_initialize (GTypeModule *module)
 {
 	couchdb_type = _couchdb_factory_get_type (module);
+	/* FIXME: this is a hack to avoid crashes when calling gnome-keyring
+	   from desktopcouch_session_new */
+	dbus_threads_init_default ();
 }
 
 void
