@@ -29,7 +29,6 @@
 #include <libedata-book/e-data-book.h>
 #include <libedata-book/e-data-book-view.h>
 #include <dbus/dbus-glib.h>
-#include <gnome-keyring.h>
 
 #define COUCHDB_UUID_PROP                    "X-COUCHDB-UUID"
 #define COUCHDB_APPLICATION_ANNOTATIONS_PROP "X-COUCHDB-APPLICATION-ANNOTATIONS"
@@ -734,12 +733,13 @@ couch_document_from_contact (EBookBackendCouchDB *couchdb_backend, EContact *con
 	document = couchdb_document_contact_new ();
 
 	str = e_contact_get_const (contact, E_CONTACT_UID);
-	if (str != NULL)
+	if (str != NULL) {
 		couchdb_document_set_id (COUCHDB_DOCUMENT (document), str);
 
-	str = g_hash_table_lookup (couchdb_backend->revisions, e_contact_get_const (contact, E_CONTACT_UID));
-	if (str != NULL)
-		couchdb_document_set_revision (COUCHDB_DOCUMENT (document), str);
+		str = g_hash_table_lookup (couchdb_backend->revisions, str);
+		if (str != NULL)
+			couchdb_document_set_revision (COUCHDB_DOCUMENT (document), str);
+	}
 
 	contact_name = (EContactName *) e_contact_get (contact, E_CONTACT_NAME);
 	if (contact_name != NULL) {
@@ -1056,20 +1056,25 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 								  db_name,
 								  &error);
 	if (couchdb_backend->database == NULL) {
-		if (error) {
+		if (error)
 			g_warning ("Could not get CouchDB database info: %s", error->message);
-			g_error_free (error);
-		}
 
 		if (only_if_exists) {
 #if EDS_CHECK_VERSION(2, 31, 0)
-			g_set_error (ret_error, ERROR_QUARK, error->code, "%s: %s",
-				     _("Could not get CouchDB database info"), error->message);
+			if (error) {
+				g_propagate_error (ret_error, error);
+				g_error_free (error);
+			} else
+				g_set_error (ret_error, ERROR_QUARK, 0, _("Could not open database %s"), db_name);
+
 			return;
 #else
 			return GNOME_Evolution_Addressbook_NoSuchBook;
 #endif
 		}
+
+		if (error)
+			g_error_free (error);
 		
 		/* if it does not exist, create it */
 		error = NULL;
@@ -1077,8 +1082,7 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 						      db_name,
 						      &error)) {
 #if EDS_CHECK_VERSION(2, 31, 0)
-			g_set_error (ret_error, ERROR_QUARK, error->code, "%s: %s",
-				     _("Could not create 'contacts' database"), error->message);
+			g_propagate_error (ret_error, error);
 #endif
 			g_warning ("Could not create 'contacts' database: %s", error->message);
 			g_error_free (error);
@@ -1129,8 +1133,9 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 
 	e_book_backend_set_is_loaded (backend, TRUE);
 	e_book_backend_set_is_writable (backend, TRUE);
-
-#if !EDS_CHECK_VERSION(2, 31, 0)
+#if EDS_CHECK_VERSION(2, 31, 0)
+	e_book_backend_notify_connection_status (backend, TRUE);
+#else
 	return GNOME_Evolution_Addressbook_Success;
 #endif
 }
